@@ -15,7 +15,7 @@ class MyWidget(TQMainWindow):
         self.setCaption(self.trUtf8("""Internationalization Example"""))
         
         self.file = TQPopupMenu(self)
-        self.file.insertItem(self.trUtf8("E&xit"), tqApp, SLOT("quit()"),
+        self.file.insertItem(self.trUtf8("E&xit"), tqApp, TQ_SLOT("quit()"),
                 TQKeySequence(self.trUtf8("Ctrl+Q","File|Quit")))
         self.menuBar().insertItem(self.trUtf8("&File"), self.file)
         
